==> MicroSweeper-1.0.13.tar.bz2: Field.java <==
/*
 * Copyright 2008,2009 Petr Machata
 *
 * This file is part of MicroSweeper.
 *
 * MicroSweeper is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * MicroSweeper is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MicroSweeper.  If not, see <http://www.gnu.org/licenses/>.
 */

class Field {
    final static int UNCOVER_BUSTED = -1;
    final static int UNCOVER_OLD = 0;
    final static int UNCOVER_NEW = 1;

    // Fundamental variables...
    public final byte index;  // coordinate
    boolean mine = false;
    boolean uncovered = false;

    // How many mines are among the participants.
    private byte parCount = 0;

    // User interface variables, stored here for ease of use (and
    // resources conservation).
    boolean flagged = false;
    boolean consistent = true;

    Field(byte index) {
	this.index = index;
    }

    Field(Field copy) {
	this.index = copy.index;
	this.mine = copy.mine;
	this.uncovered = copy.uncovered;
	this.flagged = copy.flagged;
	this.parCount = copy.parCount;
    }

    public byte getParCount() {
	return parCount;
    }

    public void setParCount(byte v) {
	parCount = v;
    }

    public int uncover() {
	if (uncovered)
	    return UNCOVER_OLD;

	uncovered = true;
	if (mine)
	    return UNCOVER_BUSTED;

	return UNCOVER_NEW;
    }

    public void toggleFlag() {
	flagged = !flagged;
    }
}

==> MicroSweeper-1.0.15.tar.bz2: Field.java <==
/*
 * Copyright 2008,2009 Petr Machata
 *
 * This file is part of MicroSweeper.
 *
 * MicroSweeper is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * MicroSweeper is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MicroSweeper.  If not, see <http://www.gnu.org/licenses/>.
 */

abstract class Field {
    final static int UNCOVER_BUSTED = -1;
    final static int UNCOVER_OLD = 0;
    final static int UNCOVER_NEW = 1;

    // Fundamental variables...
    public final byte fieldIdx;  // coordinate
    boolean mine = false;
    boolean uncovered = false;

    // How many mines are among the participants.
    protected byte parCount = 0;

    // User interface variables, stored here for ease of use (and
    // resources conservation).
    boolean flagged = false;

    protected Field(byte fieldIdx) {
	this.fieldIdx = fieldIdx;
    }

    protected Field(Field copy) {
	this.fieldIdx = copy.fieldIdx;
	this.mine = copy.mine;
	this.uncovered = copy.uncovered;
	this.flagged = copy.flagged;
	this.parCount = copy.parCount;
    }

    public byte getParCount() {
	return parCount;
    }

    public void setParCount(byte v) {
	parCount = v;
    }

    public int uncover() {
	if (uncovered)
	    return UNCOVER_OLD;

	uncovered = true;
	if (mine)
	    return UNCOVER_BUSTED;

	return UNCOVER_NEW;
    }

    public void toggleFlag() {
	flagged = !flagged;
    }

    abstract public Field clone();
    abstract public Constraint getConstraint(MineField mf);
    abstract public String render();
    abstract public int getColor();
    abstract public boolean consistent(MineField mf);
}
